<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:gco="http://www.isotc211.org/2005/gco" 
xmlns:gmd="http://www.isotc211.org/2005/gmd" xmlns:csw="http://www.opengis.net/cat/csw/2.0.2" xmlns:srv="http://www.isotc211.org/2005/srv">

	<xsl:output method="XML"></xsl:output>

	<xsl:template match="csw:GetRecordsResponse">		
		<xsl:apply-templates select="csw:SearchResults/gmd:MD_Metadata"></xsl:apply-templates>		
	</xsl:template>
	 
	<xsl:template match="gmd:MD_Metadata">
		<Metadata>
			<IDENTIFIER>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:citation/gmd:CI_Citation/gmd:identifier[1]/gmd:MD_Identifier/gmd:code/gco:CharacterString"/>
			</IDENTIFIER>
			<BBOX>
				<xsl:value-of select="concat( ./gmd:identificationInfo/*/*/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:westBoundLongitude/gco:Decimal, ' ',
														  ./gmd:identificationInfo/*/*/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:southBoundLatitude/gco:Decimal,' ',
														  ./gmd:identificationInfo/*/*/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:eastBoundLongitude/gco:Decimal,' ',
														  ./gmd:identificationInfo/*/*/gmd:EX_Extent/gmd:geographicElement/gmd:EX_GeographicBoundingBox/gmd:northBoundLatitude/gco:Decimal)"/>
			</BBOX>
			<TITLE>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:citation/gmd:CI_Citation/gmd:title/gco:CharacterString"/>
			</TITLE>
			<ABSTRACT>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:abstract/gco:CharacterString"/>
			</ABSTRACT>			
			<TOPICCATEGORY>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:topicCategory/gmd:MD_TopicCategoryCode"/>
			</TOPICCATEGORY>
			<HIERARCHYLEVEL>
				<xsl:value-of select="./gmd:hierarchyLevel/gmd:MD_ScopeCode/@codeListValue"/>
			</HIERARCHYLEVEL>
			<GEOGRDESC>
				<xsl:value-of select="./gmd:identificationInfo/*/*/gmd:EX_Extent/gmd:description/gco:CharacterString"/>
			</GEOGRDESC>	
			<CREATIONDATE>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:citation/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:date[../gmd:dateType/gmd:CI_DateTypeCode/@codeListValue = 'creation' ]/gco:DateTime"/>
			</CREATIONDATE>		
			<PUBLICATIONDATE>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:citation/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:date[../gmd:dateType/gmd:CI_DateTypeCode/@codeListValue = 'publication' ]/gco:DateTime"/>
			</PUBLICATIONDATE>
			<REVISIONDATE>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:citation/gmd:CI_Citation/gmd:date/gmd:CI_Date/gmd:date[../gmd:dateType/gmd:CI_DateTypeCode/@codeListValue = 'revision' ]/gco:DateTime"/>
			</REVISIONDATE>
			<DATA_POC_INDIVIDUALNAME>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:individualName/gco:CharacterString"/>
			</DATA_POC_INDIVIDUALNAME>			
			<DATA_POC_ORGANISATIONNAME>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:organisationName/gco:CharacterString"/>
			</DATA_POC_ORGANISATIONNAME>			
			<DATA_POC_DELIVERYPOINT>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:deliveryPoint/gco:CharacterString"/>
			</DATA_POC_DELIVERYPOINT>
			<DATA_POC_CITY>
				<xsl:value-of select="concat( ./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:postalCode/gco:CharacterString,
														   ' ', ./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:city/gco:CharacterString )"/>
			</DATA_POC_CITY>				
			<DATA_POC_COUNTRY>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:country/gco:CharacterString"/>
			</DATA_POC_COUNTRY>	
			<DATA_POC_VOICE>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:phone/gmd:CI_Telephone/gmd:voice/gco:CharacterString"/>
			</DATA_POC_VOICE>
			<DATA_POC_FACSIMILE>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:phone/gmd:CI_Telephone/gmd:facsimile/gco:CharacterString"/>
			</DATA_POC_FACSIMILE>
			<DATA_POC_EMAIL>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:address/gmd:CI_Address/gmd:electronicMailAddress/gco:CharacterString"/>
			</DATA_POC_EMAIL>
			<DATA_POC_URL>
				<xsl:value-of select="./gmd:identificationInfo/*/gmd:pointOfContact/gmd:CI_ResponsibleParty/gmd:contactInfo/gmd:CI_Contact/gmd:onlineResource/gmd:CI_OnlineResource/gmd:linkage/gmd:URL"/>
			</DATA_POC_URL>
		</Metadata>
	</xsl:template>
	
</xsl:stylesheet>