<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:fo="http://www.w3.org/1999/XSL/Format" 
	xmlns:java="java" xmlns:ows2iso="org.deegree.tibesti.OWS2ISO19119" 
	xmlns:xlink="http://www.w3.org/1999/xlink" 
	xmlns:gmd="http://www.isotc211.org/2005/gmd"
	xmlns:gco="http://www.isotc211.org/2005/gco"
	xmlns:srv="http://www.isotc211.org/2005/srv">
	<xsl:output encoding="UTF-8"></xsl:output>
	<!-- 
		start variable definitions
	-->
	<xsl:variable name="TIMESTAMP">
		<!--
		date is required but there is no way to to read its value from a WMS capabilities document; 
		instead use current timestamp default
	-->
		<xsl:value-of select="ows2iso:getCurrentTimestamp()"/>
	</xsl:variable>
	<xsl:variable name="DEFAULT_ABSTRACT">BB WMS</xsl:variable>
	<!-- 
		start template definitions
	-->
	<xsl:template match="WMT_MS_Capabilities">
		<gmd:MD_Metadata xmlns:csw="http://www.opengis.net/cat/csw" xmlns:gml="http://www.opengis.net/gml">
			<gmd:fileIdentifier>
				<gco:CharacterString>
					<xsl:value-of select="./Service/Title"/>
				</gco:CharacterString>
			</gmd:fileIdentifier>
			<gmd:language>
				<gco:CharacterString>de</gco:CharacterString>
			</gmd:language>
			<gmd:hierarchyLevel>
				<gmd:MD_ScopeCode codeList="MD_ScopeCode" codeListValue="service"/>
			</gmd:hierarchyLevel>
			<gmd:hierarchyLevelName>
				<gco:CharacterString>service</gco:CharacterString>
			</gmd:hierarchyLevelName>
			<gmd:contact>
				<xsl:choose>
					<xsl:when test="Service/ContactInformation">
						<xsl:call-template name="wms_service_respParty"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="defaultRespPartyWMS"/>
					</xsl:otherwise>
				</xsl:choose>
			</gmd:contact>
			<gmd:dateStamp>
				<gco:DateTime>
					<xsl:value-of select="$TIMESTAMP"/>
				</gco:DateTime>
			</gmd:dateStamp>
			<gmd:metadataStandardName>
					<gco:CharacterString>ISO 19115 Geographic Information Metadata</gco:CharacterString>
			</gmd:metadataStandardName>
			<gmd:metadataStandardVersion>
					<gco:CharacterString>DIS</gco:CharacterString>
			</gmd:metadataStandardVersion>
			<xsl:apply-templates select="Capability/Layer/SRS"/>
			<xsl:call-template name="identificationWMS"/>
		</gmd:MD_Metadata>
	</xsl:template>
	<xsl:template name="defaultRespPartyWMS">
		<!--
		TODO
		add a default definition for a smXML:CI_ResponsibleParty
	-->
	</xsl:template>
	<xsl:template name="wms_service_respParty">
		<!--
			template for adding a reesponsible party from service section of WMS capabilities
		-->
		<gmd:CI_ResponsibleParty>
			<xsl:if test="boolean(./Service/ContactInformation/ContactPersonPrimary/ContactPerson)">
				<gmd:individualName>
					<gco:CharacterString>
						<xsl:value-of select="./Service/ContactInformation/ContactPersonPrimary/ContactPerson"/>
					</gco:CharacterString>
				</gmd:individualName>
			</xsl:if>
			<xsl:if test="boolean(./Service/ContactInformation/ContactPersonPrimary/ContactOrganization)">
				<gmd:organisationName>
					<gco:CharacterString>
						<xsl:value-of select="./Service/ContactInformation/ContactPersonPrimary/ContactOrganization"/>
					</gco:CharacterString>
				</gmd:organisationName>
			</xsl:if>
			<gmd:contactInfo>
			<gmd:CI_Contact>
					<xsl:if test="./Service/ContactInformation/ContactVoiceTelephone or ./Service/ContactInformation/ContactFacsimileTelephone">
						<gmd:phone>
						<gmd:CI_Telephone>
								<xsl:if test="./Service/ContactInformation/ContactVoiceTelephone">
									<gmd:voice>
									<gco:CharacterString>
											<xsl:value-of select="./Service/ContactInformation/ContactVoiceTelephone"/>
										</gco:CharacterString>
									</gmd:voice>
								</xsl:if>
								<xsl:if test="./Service/ContactInformation/ContactFacsimileTelephone">
									<gmd:facsimile>
									<gco:CharacterString>
											<xsl:value-of select="./Service/ContactInformation/ContactFacsimileTelephone"/>
										</gco:CharacterString>
									</gmd:facsimile>
								</xsl:if>
							</gmd:CI_Telephone>
						</gmd:phone>
					</xsl:if>
					<xsl:if test="boolean(./Service/ContactInformation/ContactAddress)">
						<gmd:address>
							<gmd:CI_Address>
								<gmd:deliveryPoint>
									<gco:CharacterString>
										<xsl:value-of select="./Service/ContactInformation/ContactAddress/Address"/>
									</gco:CharacterString>
								</gmd:deliveryPoint>
								<gmd:city>
									<gco:CharacterString>	
										<xsl:value-of select="./Service/ContactInformation/ContactAddress/City"/>
									</gco:CharacterString>
								</gmd:city>
								<gmd:administrativeArea>
									<gco:CharacterString>
										<xsl:value-of select="./Service/ContactInformation/ContactAddress/StateOrProvince"/>
									</gco:CharacterString>
								</gmd:administrativeArea>
							<gmd:postalCode>
								<gco:CharacterString>
										<xsl:value-of select="./Service/ContactInformation/ContactAddress/PostCode"/>
									</gco:CharacterString>
								</gmd:postalCode>
								<gmd:country>
									<gco:CharacterString>
										<xsl:value-of select="./Service/ContactInformation/ContactAddress/Country"/>
									</gco:CharacterString>
								</gmd:country>
								<xsl:if test="boolean(./Service/ContactInformation/ContactElectronicMailAddress)">
									<gmd:electronicMailAddress>
										<gco:CharacterString>
											<xsl:value-of select="./Service/ContactInformation/ContactElectronicMailAddress"/>
										</gco:CharacterString>
									</gmd:electronicMailAddress>
								</xsl:if>
							</gmd:CI_Address>
						</gmd:address>
					</xsl:if>
					<xsl:if test="boolean(./Service/OnlineResource)">
						<gmd:onlineResource>
							<gmd:CI_OnlineResource>
								<gmd:linkage>
									<gmd:URL>
										<xsl:value-of select="./Service/OnlineResource/@xlink:href"/>
									</gmd:URL>
								</gmd:linkage>
							</gmd:CI_OnlineResource>
						</gmd:onlineResource>
					</xsl:if>
				</gmd:CI_Contact>
			</gmd:contactInfo>
			<gmd:role>
				<gmd:CI_RoleCode codeList="MD_ScopeCode" codeListValue="pointOfContact"/>
			</gmd:role>
		</gmd:CI_ResponsibleParty>
	</xsl:template>
	<xsl:template name="identificationWMS">
		<gmd:identificationInfo>
			<srv:SV_ServiceIdentification>
				<gmd:citation>
					<gmd:CI_Citation>
						<gmd:title>
							<gco:CharacterString>
								<xsl:value-of select="Service/Title"/>
							</gco:CharacterString>
						</gmd:title>
						<gmd:date>
							<gmd:CI_Date>
								<gmd:date>
									<gco:DateTime>
										<xsl:value-of select="$TIMESTAMP"/>
									</gco:DateTime>
								</gmd:date>
								<gmd:dateType>
									<gmd:CI_DateTypeCode codeList="http://www.isotc211.org/2005/resources/codeList.xml#CI_DateTypeCode" codeListValue="creation"/>
								</gmd:dateType>
							</gmd:CI_Date>
						</gmd:date>
					</gmd:CI_Citation>
				</gmd:citation>
				<gmd:abstract>
					<gco:CharacterString>
						<xsl:choose>
							<xsl:when test="boolean( Service/Abstract )">
								<xsl:value-of select="Service/Abstract"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$DEFAULT_ABSTRACT"/>
							</xsl:otherwise>
						</xsl:choose>
					</gco:CharacterString>
				</gmd:abstract>
				<srv:serviceType>
					<gco:LocalName>OGC:WMS</gco:LocalName>
				</srv:serviceType>
				<srv:serviceTypeVersion>
						<gco:CharacterString>1.1.1</gco:CharacterString>
				</srv:serviceTypeVersion>
				<xsl:if test="Service/Fees">
					<srv:accessProperties>
						<gmd:MD_StandardOrderProcess>
							<gmd:fees>
								<gco:CharacterString>
									<xsl:value-of select="Service/Fees"/>
								</gco:CharacterString>
							</gmd:fees>
						</gmd:MD_StandardOrderProcess>
					</srv:accessProperties>
				</xsl:if>
				<xsl:if test="Service/AccessConstraints">
					<srv:restrictions>
						<gmd:MD_LegalConstraints>
							<gmd:useLimitation>
								<gco:CharacterString>
									<xsl:value-of select="Service/AccessConstraints"/>
								</gco:CharacterString>
							</gmd:useLimitation>
						</gmd:MD_LegalConstraints>
					</srv:restrictions>
				</xsl:if>
				<xsl:apply-templates select="Capability/Layer/LatLonBoundingBox"/>
				<!-- coupldResource -->
				<xsl:apply-templates select="Capability/Layer" mode="COUPLEDRESOURCE"/>
				<srv:couplingType>
					<xsl:choose>
						<xsl:when test="Capability/UserDefinedSymbolization/@UserLayer = 1">
							<srv:SV_CouplingType codeList="http://someurl#SV_CouplingType" codeListValue="mixed"/>
						</xsl:when>
						<xsl:otherwise>
							<srv:SV_CouplingType codeList="http://someurl#SV_CouplingType" codeListValue="tight"/>
						</xsl:otherwise>
					</xsl:choose>
				</srv:couplingType>
				<xsl:call-template name="addGetCapabilitiesOpMetadata"/>
				<xsl:call-template name="addGetMapOpMetadata"/>
				<xsl:if test="boolean(Capability/Request/GetFeatureInfo)">
					<xsl:call-template name="addGetFeatureInfoOpMetadata"/>
				</xsl:if>
				<xsl:if test="boolean(Capability/Request/DescribeLayer)">
					<xsl:call-template name="addDescribeLayerOpMetadata"/>
				</xsl:if>
				<xsl:if test="boolean(Capability/Request/GetLegendGraphic)">
					<xsl:call-template name="addGetLegendGraphicOpMetadata"/>
				</xsl:if>
				<xsl:apply-templates select="Capability/Layer" mode="OPERATESON"/>
			</srv:SV_ServiceIdentification>
		</gmd:identificationInfo>
	</xsl:template>
	<xsl:template name="addGetCapabilitiesOpMetadata">
		<!--
			append GetCapabilities description
		-->
		<srv:containsOperations>
			<srv:SV_OperationMetadata>
				<srv:operationName>
					<gco:CharacterString>GetCapabilities</gco:CharacterString>
				</srv:operationName>
				<xsl:apply-templates select="Capability/Request/GetCapabilities/DCPType/HTTP"/>
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Service</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Version</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Request</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
						</srv:direction>
						<srv:description>
							<gco:CharacterString>fixed value: GetCapabilities</gco:CharacterString>
						</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>
				<xsl:choose>
					<xsl:when test="boolean(Capability/Request/GetCapabilities/DCPType/HTTP/*)">
						<xsl:apply-templates select="Capability/Request/GetCapabilities/DCPType/HTTP/Get/OnlineResource"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="Capability/Request/GetCapabilities/DCPType/HTTP/Post/OnlineResource"/>
					</xsl:otherwise>
				</xsl:choose>
		</srv:SV_OperationMetadata>
		</srv:containsOperations>
	</xsl:template>
	<xsl:template name="addGetMapOpMetadata">
		<!--
			append GetMap description
		-->
		<srv:containsOperations>
			<srv:SV_OperationMetadata>
				<srv:operationName>
					<gco:CharacterString>GetMap</gco:CharacterString>
				</srv:operationName>
				<xsl:apply-templates select="Capability/Request/GetMap/DCPType/HTTP"/>
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Version</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>			
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Request</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: GetMap</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Layers</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Styles</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>			
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>srs</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>			
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>BBOX</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>			
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>width</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>height</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Format</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>			
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>TRANSPARENT</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>boolean</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>BGCOLOR</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>EXCEPTIONS</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>TIME</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>ELEVATION</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
				<xsl:choose>
					<xsl:when test="boolean(Capability/Request/GetMap/DCPType/HTTP/*)">
						<xsl:apply-templates select="Capability/Request/GetMap/DCPType/HTTP/Get/OnlineResource"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="Capability/Request/GetMap/DCPType/HTTP/Post/OnlineResource"/>
					</xsl:otherwise>
				</xsl:choose>
			</srv:SV_OperationMetadata>
		</srv:containsOperations>
	</xsl:template>
	<xsl:template name="addGetFeatureInfoOpMetadata">
		<!--
			append GetFeatureInfo description
		-->
		<srv:containsOperations>
			<srv:SV_OperationMetadata>
				<srv:operationName>
					<gco:CharacterString>GetFeatureInfo</gco:CharacterString>
				</srv:operationName>
				<xsl:apply-templates select="Capability/Request/GetFeatureInfo/DCPType/HTTP"/>
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Version</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Request</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: GetFeatureInfo</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Layers</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Styles</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>srs</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>BBOX</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>width</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>height</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Format</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>TRANSPARENT</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>boolean</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>BGCOLOR</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>EXCEPTIONS</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>TIME</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>ELEVATION</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>QUERY_LAYERS</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>INFO_FORMAT</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>FEATURE_COUNT</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>x</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>y</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>			
				<xsl:choose>
					<xsl:when test="boolean(Capability/Request/GetFeatureInfo/DCPType/HTTP/*)">
						<xsl:apply-templates select="Capability/Request/GetFeatureInfo/DCPType/HTTP/Get/OnlineResource"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="Capability/Request/GetFeatureInfo/DCPType/HTTP/Post/OnlineResource"/>
					</xsl:otherwise>
				</xsl:choose>
			</srv:SV_OperationMetadata>
		</srv:containsOperations>
	</xsl:template>
	<xsl:template name="addDescribeLayerOpMetadata">
		<!--
			append DescribeLayer description
		-->
		<srv:containsOperations>
			<srv:SV_OperationMetadata>
				<srv:operationName>
					<gco:CharacterString>DescribeLayer</gco:CharacterString>
				</srv:operationName>
				<xsl:apply-templates select="Capability/Request/DescribeLayer/DCPType/HTTP"/>
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Version</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Request</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Layers</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>
				<xsl:choose>
					<xsl:when test="boolean(Capability/Request/DescribeLayer/DCPType/HTTP/*)">
						<xsl:apply-templates select="Capability/Request/DescribeLayer/DCPType/HTTP/Get/OnlineResource"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="Capability/Request/DescribeLayer/DCPType/HTTP/Post/OnlineResource"/>
					</xsl:otherwise>
				</xsl:choose>
		</srv:SV_OperationMetadata>
		</srv:containsOperations>
	</xsl:template>
	<xsl:template name="addGetLegendGraphicOpMetadata">
		<!--
			append GetLegendGraphic description
		-->
		<srv:containsOperations>
			<srv:SV_OperationMetadata>
				<srv:operationName>
					<gco:CharacterString>GetLegendGraphic</gco:CharacterString>
				</srv:operationName>
				<xsl:apply-templates select="Capability/Request/GetLegendGraphic/DCPType/HTTP"/>
				<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Version</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Request</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: GetLegendGraphic</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Layer</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>Style</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>FEATURETYPE</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>-</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>RULE</gco:CharacterString>
							</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>SCALE</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>SLD</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>SLD_BODY</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>FORMAT</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>mandatory</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>				
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>WIDTH</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>HEIGHT</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>integer</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>	
			<srv:parameters>
				<srv:SV_Parameter>
					<srv:name>
						<gco:aName>
							<gco:CharacterString>EXCEPTIONS</gco:CharacterString>
						</gco:aName>
						<gco:attributeType>
							<gco:TypeName>
								<gco:aName>
									<gco:CharacterString>String</gco:CharacterString>
								</gco:aName>
							</gco:TypeName>
						</gco:attributeType>
					</srv:name>
					<srv:direction>
						<srv:SV_ParameterDirection>in</srv:SV_ParameterDirection>
					</srv:direction>
					<srv:description>
						<gco:CharacterString>fixed value: DescribeLayer</gco:CharacterString>
					</srv:description>
					<srv:optionality>
						<gco:CharacterString>optional</gco:CharacterString>
					</srv:optionality>
					<srv:repeatability>
						<gco:Boolean>false</gco:Boolean>
					</srv:repeatability>
					<srv:valueType>
						<gco:TypeName>
							<gco:aName>
								<gco:CharacterString>String</gco:CharacterString>
							</gco:aName>						
						</gco:TypeName>
					</srv:valueType>
				</srv:SV_Parameter>
			</srv:parameters>
				<xsl:choose>
					<xsl:when test="boolean(Capability/Request/GetLegendGraphic/DCPType/HTTP/*)">
						<xsl:apply-templates select="Capability/Request/GetLegendGraphic/DCPType/HTTP/Get/OnlineResource"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="Capability/Request/GetLegendGraphic/DCPType/HTTP/Post/OnlineResource"/>
					</xsl:otherwise>
				</xsl:choose>	
			</srv:SV_OperationMetadata>
			</srv:containsOperations>
	</xsl:template>
	<xsl:template match="HTTP">
		<xsl:if test="boolean(Get)">
			<srv:DCP>
				<srv:DCPList codeList="http://www.example.com" codeListValue="HTTPGet"/>
			</srv:DCP>
		</xsl:if>
		<xsl:if test="boolean(Post)">
			<srv:DCP>
				<srv:DCPList codeList="http://www.example.com" codeListValue="HTTPPost"/>
			</srv:DCP>
		</xsl:if>
	</xsl:template>
	<xsl:template match="OnlineResource">
		<srv:connectPoint>
			<gmd:CI_OnlineResource>
			<gmd:linkage>
				<gmd:URL>
						<xsl:value-of select="./@xlink:href"/>
					</gmd:URL>
				</gmd:linkage>
			</gmd:CI_OnlineResource>
		</srv:connectPoint>
	</xsl:template>
	
	<xsl:template match="Layer" mode="OPERATESON">
		<xsl:if test="boolean(Name)">
			<srv:operatesOn>
				<gmd:MD_DataIdentification>
					<gmd:citation>
						<gmd:CI_Citation>
							<gmd:title>
								<gco:CharacterString>
									<xsl:value-of select="Title"/>
								</gco:CharacterString>
							</gmd:title>
							<gmd:date>
								<!--
									date is required but there is no way to to read its value from a WMS capabilities
									document; instead use current timestamp and revision as default
								-->
								<gmd:CI_Date>
									<gmd:date>
										<gco:DateTime>
											<xsl:value-of select="$TIMESTAMP"/>
										</gco:DateTime>
									</gmd:date>
									<gmd:dateType>
										<gmd:CI_DateTypeCode codeList="http://www.isotc211.org/2005/resources/codeList.xml#CI_DateTypeCode" codeListValue="revision"/>
									</gmd:dateType>
								</gmd:CI_Date>
							</gmd:date>
							<gmd:identifier>
								<gmd:MD_Identifier>
									<gmd:code>
										<gco:CharacterString>
											<xsl:value-of select="Name"/>
										</gco:CharacterString>
									</gmd:code>
								</gmd:MD_Identifier>
							</gmd:identifier>
						</gmd:CI_Citation>
					</gmd:citation>
					<xsl:choose>
						<xsl:when test="Abstract">
							<gmd:abstract>
								<gco:CharacterString>
									<xsl:value-of select="Abstract"/>
								</gco:CharacterString>
							</gmd:abstract>
						</xsl:when>
						<xsl:otherwise>
							<gmd:abstract>
								<gco:CharacterString>
									<!-- use layer title as default abstract -->
									<xsl:value-of select="Title"/>
								</gco:CharacterString>
							</gmd:abstract>
						</xsl:otherwise>
					</xsl:choose>
					<gmd:language>
						<gco:CharacterString>de</gco:CharacterString>
					</gmd:language>
					<gmd:topicCategory>
						<!--
							topicCategory is required but there is no way to read its value from a WMS capabilities
							document nor to set a meaningful default
						-->
						<gmd:MD_TopicCategoryCode>environment</gmd:MD_TopicCategoryCode>
					</gmd:topicCategory>
				</gmd:MD_DataIdentification>
			</srv:operatesOn>
		</xsl:if>
		<xsl:apply-templates select="Layer" mode="OPERATESON"/>
	</xsl:template>
	
	<xsl:template match="Layer" mode="COUPLEDRESOURCE">
		<xsl:if test="boolean(Name)">
			<srv:coupledResource>
				<srv:SV_CoupledResource>
					<srv:operationName>
						<gco:CharacterString>GetMap</gco:CharacterString>
					</srv:operationName>
					<srv:identifier>
						<gco:CharacterString>
							<xsl:value-of select="Name"/>
						</gco:CharacterString>
					</srv:identifier>
					<gco:ScopedName>
						<xsl:value-of select="Name"/>
					</gco:ScopedName>
				</srv:SV_CoupledResource>
			</srv:coupledResource>
			<xsl:variable name="QUERYABLE">
				<xsl:value-of select="@queryable"/>
			</xsl:variable>
			<xsl:if test="boolean( $QUERYABLE = 1 )">
				<srv:coupledResource>
					<srv:SV_CoupledResource>
						<srv:operationName>
							<gco:CharacterString>GetFeatureInfo</gco:CharacterString>
						</srv:operationName>
						<srv:identifier>
							<gco:CharacterString>
								<xsl:value-of select="Name"/>
							</gco:CharacterString>
						</srv:identifier>
						<gco:ScopedName>
							<xsl:value-of select="Name"/>
						</gco:ScopedName>
					</srv:SV_CoupledResource>
				</srv:coupledResource>
			</xsl:if>
		</xsl:if>
		<xsl:apply-templates select="Layer" mode="COUPLEDRESOURCE" />
	</xsl:template>
	
	<xsl:template match="LatLonBoundingBox">
		<srv:extent>
			<gmd:EX_Extent>
				<gmd:geographicElement>
					<gmd:EX_GeographicBoundingBox>
						<gmd:westBoundLongitude>
							<gco:Decimal>
								<xsl:value-of select="format-number(./@minx, '###.##' )"/>
							</gco:Decimal>
						</gmd:westBoundLongitude>
						<gmd:eastBoundLongitude>
							<gco:Decimal>
								<xsl:value-of select="format-number(./@maxx, '###.##' )"/>
							</gco:Decimal>
						</gmd:eastBoundLongitude>
						<gmd:southBoundLatitude>
							<gco:Decimal>
								<xsl:value-of select="format-number(./@miny, '###.##' )"/>
							</gco:Decimal>
						</gmd:southBoundLatitude>
						<gmd:northBoundLatitude>
							<gco:Decimal>
								<xsl:value-of select="format-number(./@maxy, '###.##' )"/>
							</gco:Decimal>
						</gmd:northBoundLatitude>
					</gmd:EX_GeographicBoundingBox>
				</gmd:geographicElement>
			</gmd:EX_Extent>
		</srv:extent>
	</xsl:template>
	<xsl:template match="SRS">
		<gmd:referenceSystemInfo>
			<gmd:MD_ReferenceSystem>
				<gmd:referenceSystemIdentifier>
					<gmd:RS_Identifier>
						<gmd:code>
							<gco:CharacterString>
								<xsl:value-of select="."/>
							</gco:CharacterString>
						</gmd:code>
					</gmd:RS_Identifier>
				</gmd:referenceSystemIdentifier>
			</gmd:MD_ReferenceSystem>
		</gmd:referenceSystemInfo>
	</xsl:template>
</xsl:stylesheet>
